** Replication file: Gerring et al. (2013). "Assessing Health System Performance: A Model-based Approach," Social Science & Medicine, 93: 21-28.

* Load data (note: imputation of missing values carried out using Amelia II)
use "~/Dropbox/SSM_replication/SSM_data.dta", clear

* Table 1: Correlation between human development indicators
gen ln_child_mortality = ln(child_mortality)
gen ln_infant_mortality = ln(infant_mortality)
gen infant_mortality_invert = -(ln(infant_mortality))
pca life_expectancy infant_mortality_invert if imp==0
predict pc1 pc2, score
correlate pc1 pc2
pwcorr pc1 life_expectancy ln_infant_mortality HALE_male HALE_females DALY ln_child_mortality malnutrition poverty HDI if imp==0
drop pc1 pc2 infant_mortality_invert ln_child_mortality ln_infant_mortality

* Figure 1: Global distribution of public health by country
kdensity health_performance if year == 1960 & imp!=0, lcolor(black) lpattern(solid) xli(-1.040721, lcolor(black) lpattern(solid)) graphregion(color(white)) title("") note("") plot(kdensity health_performance if year == 2010 & imp!=0,  lcolor(black) lpattern(dash) xli(.8969982, lcolor(black) lpattern(dash)))  legend(label(1 "1960") label(2 "2010") rows(1))

* Table 2: A cross-sectional model of public health performance
use "~/Dropbox/SSM_replication/SSM_data.dta", clear
mi import flong, m(imp) id(year Banks) imp(population poverty life_expectancy infant_mortality ln_gdp_per_cap HIV TB literacy malaria urban English_legal_origin French_legal_origin German_legal_origin Scandinavian_legal_origin latitude boreal destmp destrp polar subtrop tropics water wettemp Buddhism Catholic Muslim Protestant yr_sch HIV_geo TB_geo malaria_geo health_performance ln_gdp_per_cap_sq ln_gdp_per_cap_cu health_expenditure telephones gini tax_revenue oil_production polity2 growth imports) 
mi register regular y1961-y2010 child_mortality malnutrition island DALY HALE_females HALE_male landlock OECD HDI conflict
mi stset, clear
mi estimate, post: reg health_performance HIV_geo TB_geo malaria_geo ln_gdp_per_cap ln_gdp_per_cap_sq ln_gdp_per_cap_cu urban yr_sch literacy Catholic Muslim Protestant English_legal_origin French_legal_origin German_legal_origin Scandinavian_legal_origin island latitude landlock boreal destmp subtrop tropics wettemp destrp water y1961-y2010

* Table 3: Over- and under-performers
* Note: Calculating the residuals, as done below, will take some time.
predict yhat_ach
gen error_ach = health_performance - yhat_ach
predict se_error_ach if error!=., stdp
gen ci_error_ach = 1.64 * se_error_ach
gen error_ach_avg = .
gen ci_error_ach_avg = .
forval x = 10/2600 {
quietly sum error_ach if Banks == `x' & year == 1960
quietly replace error_ach_avg = r(mean) if Banks == `x' & year == 1960
}
forval x = 10/2600 {
quietly sum error_ach if Banks == `x' & year == 1961
quietly replace error_ach_avg = r(mean) if Banks == `x' & year == 1961
}
forval x = 10/2600 {
quietly sum error_ach if Banks == `x' & year == 1962
quietly replace error_ach_avg = r(mean) if Banks == `x' & year == 1962
}
forval x = 10/2600 {
quietly sum error_ach if Banks == `x' & year == 1963
quietly replace error_ach_avg = r(mean) if Banks == `x' & year == 1963
}
forval x = 10/2600 {
quietly sum error_ach if Banks == `x' & year == 1964
quietly replace error_ach_avg = r(mean) if Banks == `x' & year == 1964
}
forval x = 10/2600 {
quietly sum error_ach if Banks == `x' & year == 1965
quietly replace error_ach_avg = r(mean) if Banks == `x' & year == 1965
}
forval x = 10/2600 {
quietly sum error_ach if Banks == `x' & year == 1966
quietly replace error_ach_avg = r(mean) if Banks == `x' & year == 1966
}
forval x = 10/2600 {
quietly sum error_ach if Banks == `x' & year == 1967
quietly replace error_ach_avg = r(mean) if Banks == `x' & year == 1967
}
forval x = 10/2600 {
quietly sum error_ach if Banks == `x' & year == 1968
quietly replace error_ach_avg = r(mean) if Banks == `x' & year == 1968
}
forval x = 10/2600 {
quietly sum error_ach if Banks == `x' & year == 1969
quietly replace error_ach_avg = r(mean) if Banks == `x' & year == 1969
}
forval x = 10/2600 {
quietly sum error_ach if Banks == `x' & year == 1970
quietly replace error_ach_avg = r(mean) if Banks == `x' & year == 1970
}
forval x = 10/2600 {
quietly sum error_ach if Banks == `x' & year == 1971
quietly replace error_ach_avg = r(mean) if Banks == `x' & year == 1971
}
forval x = 10/2600 {
quietly sum error_ach if Banks == `x' & year == 1972
quietly replace error_ach_avg = r(mean) if Banks == `x' & year == 1972
}
forval x = 10/2600 {
quietly sum error_ach if Banks == `x' & year == 1973
quietly replace error_ach_avg = r(mean) if Banks == `x' & year == 1973
}
forval x = 10/2600 {
quietly sum error_ach if Banks == `x' & year == 1974
quietly replace error_ach_avg = r(mean) if Banks == `x' & year == 1974
}
forval x = 10/2600 {
quietly sum error_ach if Banks == `x' & year == 1975
quietly replace error_ach_avg = r(mean) if Banks == `x' & year == 1975
}
forval x = 10/2600 {
quietly sum error_ach if Banks == `x' & year == 1976
quietly replace error_ach_avg = r(mean) if Banks == `x' & year == 1976
}
forval x = 10/2600 {
quietly sum error_ach if Banks == `x' & year == 1977
quietly replace error_ach_avg = r(mean) if Banks == `x' & year == 1977
}
forval x = 10/2600 {
quietly sum error_ach if Banks == `x' & year == 1978
quietly replace error_ach_avg = r(mean) if Banks == `x' & year == 1978
}
forval x = 10/2600 {
quietly sum error_ach if Banks == `x' & year == 1979
quietly replace error_ach_avg = r(mean) if Banks == `x' & year == 1979
}
forval x = 10/2600 {
quietly sum error_ach if Banks == `x' & year == 1980
quietly replace error_ach_avg = r(mean) if Banks == `x' & year == 1980
}
forval x = 10/2600 {
quietly sum error_ach if Banks == `x' & year == 1981
quietly replace error_ach_avg = r(mean) if Banks == `x' & year == 1981
}
forval x = 10/2600 {
quietly sum error_ach if Banks == `x' & year == 1982
quietly replace error_ach_avg = r(mean) if Banks == `x' & year == 1982
}
forval x = 10/2600 {
quietly sum error_ach if Banks == `x' & year == 1983
quietly replace error_ach_avg = r(mean) if Banks == `x' & year == 1983
}
forval x = 10/2600 {
quietly sum error_ach if Banks == `x' & year == 1984
quietly replace error_ach_avg = r(mean) if Banks == `x' & year == 1984
}
forval x = 10/2600 {
quietly sum error_ach if Banks == `x' & year == 1985
quietly replace error_ach_avg = r(mean) if Banks == `x' & year == 1985
}
forval x = 10/2600 {
quietly sum error_ach if Banks == `x' & year == 1986
quietly replace error_ach_avg = r(mean) if Banks == `x' & year == 1986
}
forval x = 10/2600 {
quietly sum error_ach if Banks == `x' & year == 1987
quietly replace error_ach_avg = r(mean) if Banks == `x' & year == 1987
}
forval x = 10/2600 {
quietly sum error_ach if Banks == `x' & year == 1988
quietly replace error_ach_avg = r(mean) if Banks == `x' & year == 1988
}
forval x = 10/2600 {
quietly sum error_ach if Banks == `x' & year == 1989
quietly replace error_ach_avg = r(mean) if Banks == `x' & year == 1989
}
forval x = 10/2600 {
quietly sum error_ach if Banks == `x' & year == 1990
quietly replace error_ach_avg = r(mean) if Banks == `x' & year == 1990
}
forval x = 10/2600 {
quietly sum error_ach if Banks == `x' & year == 1991
quietly replace error_ach_avg = r(mean) if Banks == `x' & year == 1991
}
forval x = 10/2600 {
quietly sum error_ach if Banks == `x' & year == 1992
quietly replace error_ach_avg = r(mean) if Banks == `x' & year == 1992
}
forval x = 10/2600 {
quietly sum error_ach if Banks == `x' & year == 1993
quietly replace error_ach_avg = r(mean) if Banks == `x' & year == 1993
}
forval x = 10/2600 {
quietly sum error_ach if Banks == `x' & year == 1994
quietly replace error_ach_avg = r(mean) if Banks == `x' & year == 1994
}
forval x = 10/2600 {
quietly sum error_ach if Banks == `x' & year == 1995
quietly replace error_ach_avg = r(mean) if Banks == `x' & year == 1995
}
forval x = 10/2600 {
quietly sum error_ach if Banks == `x' & year == 1996
quietly replace error_ach_avg = r(mean) if Banks == `x' & year == 1996
}
forval x = 10/2600 {
quietly sum error_ach if Banks == `x' & year == 1997
quietly replace error_ach_avg = r(mean) if Banks == `x' & year == 1997
}
forval x = 10/2600 {
quietly sum error_ach if Banks == `x' & year == 1998
quietly replace error_ach_avg = r(mean) if Banks == `x' & year == 1998
}
forval x = 10/2600 {
quietly sum error_ach if Banks == `x' & year == 1999
quietly replace error_ach_avg = r(mean) if Banks == `x' & year == 1999
}
forval x = 10/2600 {
quietly sum error_ach if Banks == `x' & year == 2000
quietly replace error_ach_avg = r(mean) if Banks == `x' & year == 2000
}
forval x = 10/2600 {
quietly sum error_ach if Banks == `x' & year == 2001
quietly replace error_ach_avg = r(mean) if Banks == `x' & year == 2001
}
forval x = 10/2600 {
quietly sum error_ach if Banks == `x' & year == 2002
quietly replace error_ach_avg = r(mean) if Banks == `x' & year == 2002
}
forval x = 10/2600 {
quietly sum error_ach if Banks == `x' & year == 2003
quietly replace error_ach_avg = r(mean) if Banks == `x' & year == 2003
}
forval x = 10/2600 {
quietly sum error_ach if Banks == `x' & year == 2004
quietly replace error_ach_avg = r(mean) if Banks == `x' & year == 2004
}
forval x = 10/2600 {
quietly sum error_ach if Banks == `x' & year == 2005
quietly replace error_ach_avg = r(mean) if Banks == `x' & year == 2005
}
forval x = 10/2600 {
quietly sum error_ach if Banks == `x' & year == 2006
quietly replace error_ach_avg = r(mean) if Banks == `x' & year == 2006
}
forval x = 10/2600 {
quietly sum error_ach if Banks == `x' & year == 2007
quietly replace error_ach_avg = r(mean) if Banks == `x' & year == 2007
}
forval x = 10/2600 {
quietly sum error_ach if Banks == `x' & year == 2008
quietly replace error_ach_avg = r(mean) if Banks == `x' & year == 2008
}
forval x = 10/2600 {
quietly sum error_ach if Banks == `x' & year == 2009
quietly replace error_ach_avg = r(mean) if Banks == `x' & year == 2009
}
forval x = 10/2600 {
quietly sum error_ach if Banks == `x' & year == 2010
quietly replace error_ach_avg = r(mean) if Banks == `x' & year == 2010
quietly sum ci_error_ach if Banks == `x' & year == 2010
quietly replace ci_error_ach_avg = r(mean) if Banks == `x' & year == 2010
}
gen exclude = .
replace exclude = 1 if Banks == 10 | Banks == 20 | Banks == 32 | Banks == 37 | Banks == 854 | Banks == 327 | Banks == 475 | Banks == 631 | Banks == 700 | Banks == 705 | Banks == 785 | Banks == 140 | Banks == 905 | Banks == 1270 | Banks == 982 | Banks == 1030 | Banks == 1063 | Banks == 1175
* Achievement, 2010
br countryname error_ach_avg ci_error_ach_avg exclude if year == 2010 & _mi_m == 1
* Improvement, 1960-2010
gen indexfirst=.
gen indexlast=.
gen indexfirstci=.
gen indexlastci=.
do "~/Dropbox/SSM_replication/SSM_improvement.do"
gen improve = indexlast - indexfirst
gen improveci = indexfirstci + indexlastci
br countryname improve improveci exclude if year == 2010 & _mi_m == 1

* Table 4: Country fixed-effect model of public health performance
mi xtset Banks year
mi estimate, post: xtreg health_performance HIV_geo TB_geo malaria_geo ln_gdp_per_cap ln_gdp_per_cap_sq ln_gdp_per_cap_cu urban yr_sch literacy y1961-y2010, fe

* Figure 3: Residuals from the country fixed-effect model
mi estimate, post: xtreg health_performance HIV_geo TB_geo malaria_geo ln_gdp_per_cap ln_gdp_per_cap_sq ln_gdp_per_cap_cu urban yr_sch literacy y1961-y2010, fe
gen error_imp_avg = .
predict yhat_imp
gen error_imp = health_performance - yhat_imp
forval x = 1960/2010 {
quietly sum error_imp if Banks == 1200 & year == `x'
quietly replace error_imp_avg = r(mean) if Banks == 1200 & year == `x'
}
label variable error_imp_avg "Residuals"
label variable year "Year"
* Graph residuals for Egypt
graph twoway bar error_imp_avg year if Banks == 1200 & _mi_m == 1, title("Egypt", color(black)) graphregion(color(white))

* Table 5: Robustness tests
use "~/Dropbox/SSM_replication/SSM_data.dta", clear
quietly mi import flong, m(imp) id(year Banks) imp(population poverty life_expectancy infant_mortality ln_gdp_per_cap HIV TB literacy malaria urban English_legal_origin French_legal_origin German_legal_origin Scandinavian_legal_origin latitude boreal destmp destrp polar subtrop tropics water wettemp Buddhism Catholic Muslim Protestant yr_sch HIV_geo TB_geo malaria_geo health_performance ln_gdp_per_cap_sq ln_gdp_per_cap_cu health_expenditure telephones gini tax_revenue oil_production polity2 growth imports) 
quietly mi register regular y1961-y2010 child_mortality malnutrition island DALY HALE_females HALE_male landlock OECD HDI conflict
quietly mi stset, clear
quietly mi estimate, post: reg health_performance HIV_geo TB_geo malaria_geo ln_gdp_per_cap ln_gdp_per_cap_sq ln_gdp_per_cap_cu urban yr_sch literacy Catholic Muslim Protestant English_legal_origin French_legal_origin German_legal_origin Scandinavian_legal_origin island latitude landlock boreal destmp subtrop tropics wettemp destrp water y1961-y2010
quietly predict yhat_ach
quietly gen error_ach = health_performance - yhat_ach
quietly mi xtset Banks year
quietly mi estimate, post: xtreg health_performance HIV_geo TB_geo malaria_geo ln_gdp_per_cap ln_gdp_per_cap_sq ln_gdp_per_cap_cu urban yr_sch literacy y1961-y2010, fe
quietly predict yhat_imp
quietly gen error_imp = health_performance - yhat_imp
* Life expectency only
quietly mi xtset, clear
quietly mi estimate, post: reg life_expectancy HIV_geo TB_geo malaria_geo ln_gdp_per_cap ln_gdp_per_cap_sq ln_gdp_per_cap_cu urban yr_sch literacy Catholic Muslim Protestant English_legal_origin French_legal_origin German_legal_origin Scandinavian_legal_origin island latitude landlock boreal destmp subtrop tropics wettemp destrp water y1961-y2010
quietly predict yhat_1
quietly gen res_1 = life_expectancy - yhat_1
spearman error_ach res_1
corr error_ach res_1
drop yhat_1 res_1
quietly mi xtset Banks year
quietly mi estimate, post: xtreg life_expectancy HIV_geo TB_geo malaria_geo ln_gdp_per_cap ln_gdp_per_cap_sq ln_gdp_per_cap_cu urban yr_sch literacy y1961-y2010, fe
quietly predict yhat_1
quietly gen res_1 = life_expectancy - yhat_1
spearman error_imp res_1
corr error_imp res_1
drop yhat_1 res_1
* IMR (ln) only
gen ln_infant_mortality = ln(infant_mortality)
quietly mi xtset, clear
quietly mi estimate, post: reg ln_infant_mortality HIV_geo TB_geo malaria_geo ln_gdp_per_cap ln_gdp_per_cap_sq ln_gdp_per_cap_cu urban yr_sch literacy Catholic Muslim Protestant English_legal_origin French_legal_origin German_legal_origin Scandinavian_legal_origin island latitude landlock boreal destmp subtrop tropics wettemp destrp water y1961-y2010
quietly predict yhat_1
quietly gen res_1 = ln_infant_mortality - yhat_1
spearman error_ach res_1
corr error_ach res_1
drop yhat_1 res_1
quietly mi xtset Banks year
quietly mi estimate, post: xtreg ln_infant_mortality HIV_geo TB_geo malaria_geo ln_gdp_per_cap ln_gdp_per_cap_sq ln_gdp_per_cap_cu urban yr_sch literacy y1961-y2010, fe
quietly predict yhat_1
quietly gen res_1 = ln_infant_mortality - yhat_1
spearman error_imp res_1
corr error_imp res_1
drop yhat_1 res_1 ln_infant_mortality
* Subtract HIV, TB, and malaria
quietly mi xtset, clear
quietly mi estimate, post: reg health_performance ln_gdp_per_cap ln_gdp_per_cap_sq ln_gdp_per_cap_cu urban yr_sch literacy Catholic Muslim Protestant English_legal_origin French_legal_origin German_legal_origin Scandinavian_legal_origin island latitude landlock boreal destmp subtrop tropics wettemp destrp water y1961-y2010
quietly predict yhat_1
quietly gen res_1 = health_performance - yhat_1
spearman error_ach res_1
corr error_ach res_1
drop yhat_1 res_1
quietly mi xtset Banks year
quietly mi estimate, post: xtreg health_performance ln_gdp_per_cap ln_gdp_per_cap_sq ln_gdp_per_cap_cu urban yr_sch literacy y1961-y2010, fe
quietly predict yhat_1
quietly gen res_1 = health_performance - yhat_1
spearman error_imp res_1
corr error_imp res_1
drop yhat_1 res_1
* Subtract GDP's
quietly mi xtset, clear
quietly mi estimate, post: reg health_performance HIV_geo TB_geo malaria_geo urban yr_sch literacy Catholic Muslim Protestant English_legal_origin French_legal_origin German_legal_origin Scandinavian_legal_origin island latitude landlock boreal destmp subtrop tropics wettemp destrp water y1961-y2010
quietly predict yhat_1
quietly gen res_1 = health_performance - yhat_1
spearman error_ach res_1
corr error_ach res_1
drop yhat_1 res_1
quietly mi xtset Banks year
quietly mi estimate, post: xtreg health_performance HIV_geo TB_geo malaria_geo urban yr_sch literacy y1961-y2010, fe
quietly predict yhat_1
quietly gen res_1 = health_performance - yhat_1
spearman error_imp res_1
corr error_imp res_1
drop yhat_1 res_1
* Subtract urban
quietly mi xtset, clear
quietly mi estimate, post: reg health_performance HIV_geo TB_geo malaria_geo ln_gdp_per_cap ln_gdp_per_cap_sq ln_gdp_per_cap_cu yr_sch literacy Catholic Muslim Protestant English_legal_origin French_legal_origin German_legal_origin Scandinavian_legal_origin island latitude landlock boreal destmp subtrop tropics wettemp destrp water y1961-y2010
quietly predict yhat_1
quietly gen res_1 = health_performance - yhat_1
spearman error_ach res_1
corr error_ach res_1
drop yhat_1 res_1
quietly mi xtset Banks year
quietly mi estimate, post: xtreg health_performance HIV_geo TB_geo malaria_geo ln_gdp_per_cap ln_gdp_per_cap_sq ln_gdp_per_cap_cu yr_sch literacy y1961-y2010, fe
quietly predict yhat_1
quietly gen res_1 = health_performance - yhat_1
spearman error_imp res_1
corr error_imp res_1
drop yhat_1 res_1
* Subtract geographic controls
quietly mi xtset, clear
quietly mi estimate, post: reg health_performance HIV_geo TB_geo malaria_geo ln_gdp_per_cap ln_gdp_per_cap_sq ln_gdp_per_cap_cu urban yr_sch literacy Catholic Muslim Protestant English_legal_origin French_legal_origin German_legal_origin Scandinavian_legal_origin y1961-y2010
quietly predict yhat_1
quietly gen res_1 = health_performance - yhat_1
spearman error_ach res_1
corr error_ach res_1
drop yhat_1 res_1
* Add Growth
quietly mi estimate, post: reg health_performance growth HIV_geo TB_geo malaria_geo ln_gdp_per_cap ln_gdp_per_cap_sq ln_gdp_per_cap_cu urban yr_sch literacy Catholic Muslim Protestant English_legal_origin French_legal_origin German_legal_origin Scandinavian_legal_origin island latitude landlock boreal destmp subtrop tropics wettemp destrp water y1961-y2010
quietly predict yhat_1
quietly gen res_1 = health_performance - yhat_1
spearman error_ach res_1
corr error_ach res_1
drop yhat_1 res_1
quietly mi xtset Banks year
quietly mi estimate, post: xtreg health_performance growth HIV_geo TB_geo malaria_geo ln_gdp_per_cap ln_gdp_per_cap_sq ln_gdp_per_cap_cu urban yr_sch literacy y1961-y2010, fe
quietly predict yhat_1
quietly gen res_1 = health_performance - yhat_1
spearman error_imp res_1
corr error_imp res_1
drop yhat_1 res_1
* Add Health expend
quietly mi xtset, clear
quietly mi estimate, post: reg health_performance health_expenditure HIV_geo TB_geo malaria_geo ln_gdp_per_cap ln_gdp_per_cap_sq ln_gdp_per_cap_cu urban yr_sch literacy Catholic Muslim Protestant English_legal_origin French_legal_origin German_legal_origin Scandinavian_legal_origin island latitude landlock boreal destmp subtrop tropics wettemp destrp water y1961-y2010
quietly predict yhat_1
quietly gen res_1 = health_performance - yhat_1
spearman error_ach res_1
corr error_ach res_1
drop yhat_1 res_1
quietly mi xtset Banks year
quietly mi estimate, post: xtreg health_performance health_expenditure HIV_geo TB_geo malaria_geo ln_gdp_per_cap ln_gdp_per_cap_sq ln_gdp_per_cap_cu urban yr_sch literacy y1961-y2010, fe
quietly predict yhat_1
quietly gen res_1 = health_performance - yhat_1
spearman error_imp res_1
corr error_imp res_1
drop yhat_1 res_1
* Add Imports
quietly mi xtset, clear
quietly mi estimate, post: reg health_performance imports HIV_geo TB_geo malaria_geo ln_gdp_per_cap ln_gdp_per_cap_sq ln_gdp_per_cap_cu urban yr_sch literacy Catholic Muslim Protestant English_legal_origin French_legal_origin German_legal_origin Scandinavian_legal_origin island latitude landlock boreal destmp subtrop tropics wettemp destrp water y1961-y2010
quietly predict yhat_1
quietly gen res_1 = health_performance - yhat_1
spearman error_ach res_1
corr error_ach res_1
drop yhat_1 res_1
quietly mi xtset Banks year
quietly mi estimate, post: xtreg health_performance imports HIV_geo TB_geo malaria_geo ln_gdp_per_cap ln_gdp_per_cap_sq ln_gdp_per_cap_cu urban yr_sch literacy y1961-y2010, fe
quietly predict yhat_1
quietly gen res_1 = health_performance - yhat_1
spearman error_imp res_1
corr error_imp res_1
drop yhat_1 res_1
* Add Oil production
quietly mi xtset, clear
quietly mi estimate, post: reg health_performance oil_production HIV_geo TB_geo malaria_geo ln_gdp_per_cap ln_gdp_per_cap_sq ln_gdp_per_cap_cu urban yr_sch literacy Catholic Muslim Protestant English_legal_origin French_legal_origin German_legal_origin Scandinavian_legal_origin island latitude landlock boreal destmp subtrop tropics wettemp destrp water y1961-y2010
quietly predict yhat_1
quietly gen res_1 = health_performance - yhat_1
spearman error_ach res_1
corr error_ach res_1
drop yhat_1 res_1
quietly mi xtset Banks year
quietly mi estimate, post: xtreg health_performance oil_production HIV_geo TB_geo malaria_geo ln_gdp_per_cap ln_gdp_per_cap_sq ln_gdp_per_cap_cu urban yr_sch literacy y1961-y2010, fe
quietly predict yhat_1
quietly gen res_1 = health_performance - yhat_1
spearman error_imp res_1
corr error_imp res_1
drop yhat_1 res_1
* Add Democracy
quietly mi xtset, clear
quietly mi estimate, post: reg health_performance polity2 HIV_geo TB_geo malaria_geo ln_gdp_per_cap ln_gdp_per_cap_sq ln_gdp_per_cap_cu urban yr_sch literacy Catholic Muslim Protestant English_legal_origin French_legal_origin German_legal_origin Scandinavian_legal_origin island latitude landlock boreal destmp subtrop tropics wettemp destrp water y1961-y2010
quietly predict yhat_1
quietly gen res_1 = health_performance - yhat_1
spearman error_ach res_1
corr error_ach res_1
drop yhat_1 res_1
quietly mi xtset Banks year
quietly mi estimate, post: xtreg health_performance polity2 HIV_geo TB_geo malaria_geo ln_gdp_per_cap ln_gdp_per_cap_sq ln_gdp_per_cap_cu urban yr_sch literacy y1961-y2010, fe
quietly predict yhat_1
quietly gen res_1 = health_performance - yhat_1
spearman error_imp res_1
corr error_imp res_1
drop yhat_1 res_1
* Add Tax revenue
quietly mi xtset, clear
quietly mi estimate, post: reg health_performance tax_revenue HIV_geo TB_geo malaria_geo ln_gdp_per_cap ln_gdp_per_cap_sq ln_gdp_per_cap_cu urban yr_sch literacy Catholic Muslim Protestant English_legal_origin French_legal_origin German_legal_origin Scandinavian_legal_origin island latitude landlock boreal destmp subtrop tropics wettemp destrp water y1961-y2010
quietly predict yhat_1
quietly gen res_1 = health_performance - yhat_1
spearman error_ach res_1
corr error_ach res_1
drop yhat_1 res_1
quietly mi xtset Banks year
quietly mi estimate, post: xtreg health_performance tax_revenue HIV_geo TB_geo malaria_geo ln_gdp_per_cap ln_gdp_per_cap_sq ln_gdp_per_cap_cu urban yr_sch literacy y1961-y2010, fe
quietly predict yhat_1
quietly gen res_1 = health_performance - yhat_1
spearman error_imp res_1
corr error_imp res_1
drop yhat_1 res_1
* Add Telephone
quietly mi xtset, clear
quietly mi estimate, post: reg health_performance telephones HIV_geo TB_geo malaria_geo ln_gdp_per_cap ln_gdp_per_cap_sq ln_gdp_per_cap_cu urban yr_sch literacy Catholic Muslim Protestant English_legal_origin French_legal_origin German_legal_origin Scandinavian_legal_origin island latitude landlock boreal destmp subtrop tropics wettemp destrp water y1961-y2010
quietly predict yhat_1
quietly gen res_1 = health_performance - yhat_1
spearman error_ach res_1
corr error_ach res_1
drop yhat_1 res_1
quietly mi xtset Banks year
quietly mi estimate, post: xtreg health_performance telephones HIV_geo TB_geo malaria_geo ln_gdp_per_cap ln_gdp_per_cap_sq ln_gdp_per_cap_cu urban yr_sch literacy y1961-y2010, fe
quietly predict yhat_1
quietly gen res_1 = health_performance - yhat_1
spearman error_imp res_1
corr error_imp res_1
drop yhat_1 res_1
* Add Gini
quietly mi xtset, clear
quietly mi estimate, post: reg health_performance gini HIV_geo TB_geo malaria_geo ln_gdp_per_cap ln_gdp_per_cap_sq ln_gdp_per_cap_cu urban yr_sch literacy Catholic Muslim Protestant English_legal_origin French_legal_origin German_legal_origin Scandinavian_legal_origin island latitude landlock boreal destmp subtrop tropics wettemp destrp water y1961-y2010
quietly predict yhat_1
quietly gen res_1 = health_performance - yhat_1
spearman error_ach res_1
corr error_ach res_1
drop yhat_1 res_1
quietly mi xtset Banks year
quietly mi estimate, post: xtreg health_performance gini HIV_geo TB_geo malaria_geo ln_gdp_per_cap ln_gdp_per_cap_sq ln_gdp_per_cap_cu urban yr_sch literacy y1961-y2010, fe
quietly predict yhat_1
quietly gen res_1 = health_performance - yhat_1
spearman error_imp res_1
corr error_imp res_1
drop yhat_1 res_1
* Add Conflicts
quietly mi xtset, clear
quietly mi estimate, post: reg health_performance conflict HIV_geo TB_geo malaria_geo ln_gdp_per_cap ln_gdp_per_cap_sq ln_gdp_per_cap_cu urban yr_sch literacy Catholic Muslim Protestant English_legal_origin French_legal_origin German_legal_origin Scandinavian_legal_origin island latitude landlock boreal destmp subtrop tropics wettemp destrp water y1961-y2010
quietly predict yhat_1
quietly gen res_1 = health_performance - yhat_1
spearman error_ach res_1
corr error_ach res_1
drop yhat_1 res_1
quietly mi xtset Banks year
quietly mi estimate, post: xtreg health_performance conflict HIV_geo TB_geo malaria_geo ln_gdp_per_cap ln_gdp_per_cap_sq ln_gdp_per_cap_cu urban yr_sch literacy y1961-y2010, fe
quietly predict yhat_1
quietly gen res_1 = health_performance - yhat_1
spearman error_imp res_1
corr error_imp res_1
drop yhat_1 res_1
* Exclude OECD
quietly mi xtset, clear
quietly mi estimate, post: reg health_performance HIV_geo TB_geo malaria_geo ln_gdp_per_cap ln_gdp_per_cap_sq ln_gdp_per_cap_cu urban yr_sch literacy Catholic Muslim Protestant English_legal_origin French_legal_origin German_legal_origin Scandinavian_legal_origin island latitude landlock boreal destmp subtrop tropics wettemp destrp water y1961-y2010 if OECD==0
quietly predict yhat_1
quietly gen res_1 = health_performance - yhat_1
spearman error_ach res_1
corr error_ach res_1
drop yhat_1 res_1
quietly mi xtset Banks year
quietly mi estimate, post: xtreg health_performance HIV_geo TB_geo malaria_geo ln_gdp_per_cap ln_gdp_per_cap_sq ln_gdp_per_cap_cu urban yr_sch literacy y1961-y2010 if OECD==0, fe
quietly predict yhat_1
quietly gen res_1 = health_performance - yhat_1
spearman error_imp res_1
corr error_imp res_1
drop yhat_1 res_1
